@@ -6,7 +6,7 @@ BEGIN {
   $Gentoo::Overlay::Group::INI::Section::Overlays::AUTHORITY = 'cpan:KENTNL';
 }
 {
-  $Gentoo::Overlay::Group::INI::Section::Overlays::VERSION = '0.1.0';
+  $Gentoo::Overlay::Group::INI::Section::Overlays::VERSION = '0.2.0';
 }
 
 # ABSTRACT: Final Target for [Overlays] sections.
@@ -27,6 +27,17 @@ has '_directories' => (
   handles  => { directories => elements =>, },
 );
 
+
+sub overlay_group {
+  my ( $self, @rest ) = @_;
+  require Gentoo::Overlay::Group;
+  my $group = Gentoo::Overlay::Group->new();
+  for my $path ( $self->directories ) {
+    $group->add_overlay($path);
+  }
+  return $group;
+}
+
 __PACKAGE__->meta->make_immutable;
 no Moose;
 
@@ -43,7 +54,7 @@ Gentoo::Overlay::Group::INI::Section::Overlays - Final Target for [Overlays] sec
 
 =head1 VERSION
 
-version 0.1.0
+version 0.2.0
 
 =head1 SYNOPSIS
 
@@ -62,6 +73,12 @@ This is eventually parsed and decoded into one of these objects.
 
 Tells Config::MVP that C<directory> can be specified multiple times.
 
+=head2 overlay_group
+
+Convert the data stored in this section into a Gentoo::Overlay::Group object.
+
+  $group = $section->overlay_group;
+
 =head1 AUTHOR
 
 Kent Fredric <kentnl@cpan.org>
